# Resource: {{RESOURCE_NAME}}

*A topic or theme of ongoing interest*

## Overview

**Category**: Career | Hobby | Learning | Reference | Ideas | Other
**Created**: {{DATE}}
**Last Updated**: {{DATE}}

### Why I'm Interested
*What drew me to this topic?*


## Key Information


## Useful Links & References


## Related Notes
*Other notes connected to this resource*

- [[Note 1]]
- [[Note 2]]


## Ideas & Applications
*How might I use this information?*


## Questions to Explore


## Books, Articles, Videos


---

*Resources are reference material - things you want to learn about or refer to later.*
